@@ -9,54 +9,22 @@
 -- By Gerald Combs <gerald@wireshark.org>
 -- Copyright 1998 Gerald Combs
 --
--- This program is free software; you can redistribute it and/or
--- modify it under the terms of the GNU General Public License
--- as published by the Free Software Foundation; either version 2
--- of the License, or (at your option) any later version.
---
--- This program is distributed in the hope that it will be useful,
--- but WITHOUT ANY WARRANTY; without even the implied warranty of
--- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--- GNU General Public License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+-- SPDX-License-Identifier: GPL-2.0-or-later
 
--- Set disable_lua to true to disable Lua support.
-disable_lua = false
+-- Set enable_lua to false to disable Lua support.
+enable_lua = true
 
-if disable_lua then
+if not enable_lua then
     return
 end
 
--- If set and we are running with special privileges this setting
--- tells whether scripts other than this one are to be run.
-run_user_scripts_when_superuser = false
+-- If set and Wireshark was started as (setuid) root, then the user
+-- will not be able to execute custom Lua scripts from the personal
+-- configuration directory, the -Xlua_script command line option or
+-- the Lua Evaluate menu option in the GUI.
+run_user_scripts_when_superuser = true
 
 
--- disable potentialy harmful lua functions when running superuser
-if running_superuser then
-    local hint = "has been disabled due to running Wireshark as superuser. See https://wiki.wireshark.org/CaptureSetup/CapturePrivileges for help in running Wireshark as an unprivileged user."
-    local disabled_lib = {}
-    setmetatable(disabled_lib,{ __index = function() error("this package ".. hint) end } );
-
-    dofile = function() error("dofile " .. hint) end
-    loadfile = function() error("loadfile " .. hint) end
-    loadlib = function() error("loadlib " .. hint) end
-    require = function() error("require " .. hint) end
-    os = disabled_lib
-    io = disabled_lib
-    file = disabled_lib
-end
-
--- to avoid output to stdout which can cause problems lua's print ()
--- has been suppresed so that it yields an error.
--- have print() call info() instead.
-if gui_enabled() then
-    print = info
-end
-
 function typeof(obj)
     local mt = getmetatable(obj)
     return mt and mt.__typeof or obj.__typeof or type(obj)
@@ -86,7 +54,6 @@ end
 --
 -- since 1.11.3
 function package.prepend_path(name)
-    local debug = require "debug"
     -- get the function calling this package.prepend_path function
     local dt = debug.getinfo(2, "f")
     if not dt then
@@ -215,7 +182,7 @@ wtap_encaps = {
 	["SITA"] = 100,
 	["SCCP"] = 101,
 	["BLUETOOTH_HCI"] = 102,
-	["IPMB"] = 103,
+	["IPMB_KONTRON"] = 103,
 	["IEEE802_15_4"] = 104,
 	["X2E_XORAYA"] = 105,
 	["FLEXRAY"] = 106,
@@ -224,7 +191,7 @@ wtap_encaps = {
 	["CAN20B"] = 109,
 	["LAYER1_EVENT"] = 110,
 	["X2E_SERIAL"] = 111,
-	["I2C"] = 112,
+	["I2C_LINUX"] = 112,
 	["IEEE802_15_4_NONASK_PHY"] = 113,
 	["TNEF"] = 114,
 	["USB_LINUX_MMAPPED"] = 115,
@@ -295,99 +262,52 @@ wtap_encaps = {
 	["IP_OVER_IB_PCAP"] = 180,
 	["JUNIPER_VN"] = 181,
 	["USB_DARWIN"] = 182,
-	["NORDIC_BLE"] = 183
+	["LORATAP"] = 183,
+	["3MB_ETHERNET"] = 184,
+	["VSOCK"] = 185,
+	["NORDIC_BLE"] = 186,
+	["NETMON_NET_NETEVENT"] = 187,
+	["NETMON_HEADER"] = 188,
+	["NETMON_NET_FILTER"] = 189,
+	["NETMON_NETWORK_INFO_EX"] = 190,
+	["MA_WFP_CAPTURE_V4"] = 191,
+	["MA_WFP_CAPTURE_V6"] = 192,
+	["MA_WFP_CAPTURE_2V4"] = 193,
+	["MA_WFP_CAPTURE_2V6"] = 194,
+	["MA_WFP_CAPTURE_AUTH_V4"] = 195,
+	["MA_WFP_CAPTURE_AUTH_V6"] = 196,
+	["JUNIPER_ST"] = 197,
+	["ETHERNET_MPACKET"] = 198,
+	["DOCSIS31_XRA31"] = 199,
+	["DPAUXMON"] = 200,
+	["RUBY_MARSHAL"] = 201,
+	["RFC7468"] = 202,
+	["SYSTEMD_JOURNAL"] = 203,
+	["EBHSCR"] = 204,
+	["VPP"] = 205,
+	["IEEE802_15_4_TAP"] = 206,
+	["LOG_3GPP"] = 207,
+	["USB_2_0"] = 208,
+	["MP4"] = 209,
+	["SLL2"] = 210,
+	["ZWAVE_SERIAL"] = 211,
+	["ETW"] = 212,
+	["ERI_ENB_LOG"] = 213
 }
 wtap = wtap_encaps -- for bw compatibility
 
 
--- Wiretap file types
-wtap_filetypes = {
-	["UNKNOWN"] = 0,
-	["PCAP"] = 1,
-	["PCAPNG"] = 2,
-	["PCAP_NSEC"] = 3,
-	["PCAP_AIX"] = 4,
-	["PCAP_SS991029"] = 5,
-	["PCAP_NOKIA"] = 6,
-	["PCAP_SS990417"] = 7,
-	["PCAP_SS990915"] = 8,
-	["5VIEWS"] = 9,
-	["IPTRACE_1_0"] = 10,
-	["IPTRACE_2_0"] = 11,
-	["BER"] = 12,
-	["HCIDUMP"] = 13,
-	["CATAPULT_DCT2000"] = 14,
-	["NETXRAY_OLD"] = 15,
-	["NETXRAY_1_0"] = 16,
-	["COSINE"] = 17,
-	["CSIDS"] = 18,
-	["DBS_ETHERWATCH"] = 19,
-	["ERF"] = 20,
-	["EYESDN"] = 21,
-	["NETTL"] = 22,
-	["ISERIES"] = 23,
-	["ISERIES_UNICODE"] = 24,
-	["I4BTRACE"] = 25,
-	["ASCEND"] = 26,
-	["NGSNIFFER_UNCOMPRESSED"] = 29,
-	["NGSNIFFER_COMPRESSED"] = 30,
-	["NETXRAY_1_1"] = 31,
-	["NETWORK_INSTRUMENTS"] = 33,
-	["LANALYZER"] = 34,
-	["PPPDUMP"] = 35,
-	["RADCOM"] = 36,
-	["SNOOP"] = 37,
-	["SHOMITI"] = 38,
-	["VMS"] = 39,
-	["K12"] = 40,
-	["TOSHIBA"] = 41,
-	["VISUAL_NETWORKS"] = 42,
-	["PEEKCLASSIC_V56"] = 43,
-	["PEEKCLASSIC_V7"] = 44,
-	["PEEKTAGGED"] = 45,
-	["MPEG"] = 46,
-	["K12TEXT"] = 47,
-	["NETSCREEN"] = 48,
-	["COMMVIEW"] = 49,
-	["BTSNOOP"] = 50,
-	["TNEF"] = 51,
-	["DCT3TRACE"] = 52,
-	["PACKETLOGGER"] = 53,
-	["DAINTREE_SNA"] = 54,
-	["NETSCALER_1_0"] = 55,
-	["NETSCALER_2_0"] = 56,
-	["JPEG_JFIF"] = 57,
-	["IPFIX"] = 58,
-	["MIME"] = 59,
-	["AETHRA"] = 60,
-	["MPEG_2_TS"] = 61,
-	["VWR_80211"] = 62,
-	["VWR_ETH"] = 63,
-	["CAMINS"] = 64,
-	["STANAG_4607"] = 65,
-	["NETSCALER_3_0"] = 66,
-	["LOGCAT"] = 67,
-	["LOGCAT_BRIEF"] = 68,
-	["LOGCAT_PROCESS"] = 69,
-	["LOGCAT_TAG"] = 70,
-	["LOGCAT_THREAD"] = 71,
-	["LOGCAT_TIME"] = 72,
-	["LOGCAT_THREADTIME"] = 73,
-	["LOGCAT_LONG"] = 74,
-	["COLASOFT_CAPSA"] = 75,
-	["COLASOFT_PACKET_BUILDER"] = 76,
-	["JSON"] = 77,
-	["NETSCALER_3_5"] = 78,
-	["NETTRACE_3GPP_32_423"] = 79,
-	["MPLOG"] = 80,
-	["TSPREC_SEC"] = 0,
-	["TSPREC_DSEC"] = 1,
-	["TSPREC_CSEC"] = 2,
-	["TSPREC_MSEC"] = 3,
-	["TSPREC_USEC"] = 6,
-	["TSPREC_NSEC"] = 9
-}
-
+--
+-- Generate the wtap_filetypes items for file types, for backwards
+-- compatibility.
+-- We no longer have WTAP_FILE_TYPE_SUBTYPE_ #defines;
+-- built-in file types are registered the same way that
+-- plugin file types are registered.
+--
+-- New code should use wtap_name_to_file_type_subtype to
+-- look up file types by name.
+--
+wtap_filetypes = get_wtap_filetypes()
 
 -- Wiretap timestamp precision types
 wtap_tsprecs = {
@@ -446,16 +366,16 @@ ftypes = {
 	["IPv6"] = 33,
 	["IPXNET"] = 34,
 	["FRAMENUM"] = 35,
-	["PCRE"] = 36,
-	["GUID"] = 37,
-	["OID"] = 38,
-	["EUI64"] = 39,
-	["AX25"] = 40,
-	["VINES"] = 41,
-	["REL_OID"] = 42,
-	["SYSTEM_ID"] = 43,
-	["STRINGZPAD"] = 44,
-	["FCWWN"] = 45
+	["GUID"] = 36,
+	["OID"] = 37,
+	["EUI64"] = 38,
+	["AX25"] = 39,
+	["VINES"] = 40,
+	["REL_OID"] = 41,
+	["SYSTEM_ID"] = 42,
+	["STRINGZPAD"] = 43,
+	["FCWWN"] = 44,
+	["STRINGZTRUNC"] = 45
 }
 
 
@@ -466,7 +386,9 @@ frametype = {
 	["REQUEST"] = 1,
 	["RESPONSE"] = 2,
 	["ACK"] = 3,
-	["DUP_ACK"] = 4
+	["DUP_ACK"] = 4,
+	["RETRANS_PREV"] = 5,
+	["RETRANS_NEXT"] = 6
 }
 
 
@@ -477,6 +399,8 @@ wtap_rec_types = {
 	["FT_SPECIFIC_EVENT"] = 1,  -- file-type-specific event 
 	["FT_SPECIFIC_REPORT"] = 2,  -- file-type-specific report 
 	["SYSCALL"] = 3,  -- system call 
+	["SYSTEMD_JOURNAL_EXPORT"] = 4,  -- systemd journal entry 
+	["CUSTOM_BLOCK"] = 5,  -- pcapng custom block 
 }
 
 
@@ -486,9 +410,6 @@ wtap_presence_flags = {
 	["TS"] = 1,  -- time stamp 
 	["CAP_LEN"] = 2,  -- captured length separate from on-the-network length 
 	["INTERFACE_ID"] = 4,  -- interface ID 
-	["COMMENTS"] = 8,  -- comments 
-	["DROP_COUNT"] = 16,  -- drop count 
-	["PACK_FLAGS"] = 32,  -- packet flags 
 }
 
 
@@ -512,29 +433,23 @@ base = {
 	["PT_TCP"] = 14,  -- TCP port
 	["PT_DCCP"] = 15,  -- DCCP port
 	["PT_SCTP"] = 16,  -- SCTP port
+	["OUI"] = 17,  -- OUI resolution
+	["RANGE_STRING"] = 256,  -- Use the supplied range string to convert the field to text
 	["UNIT_STRING"] = 4096,  -- Add unit text to the field value
 	["LOCAL"] = 1000,  -- local time in our time zone, with month and day
 	["UTC"] = 1001,  -- UTC, with month and day
 	["DOY_UTC"] = 1002,  -- UTC, with 1-origin day-of-year
+	["NTP_UTC"] = 1003,  -- UTC, with "NULL" when timestamp is all zeros
 }
 
 
 -- Encodings
 ENC_BIG_ENDIAN = 0
 ENC_LITTLE_ENDIAN = 2147483648
-ENC_TIME_TIMESPEC = 0
-ENC_TIME_NTP = 2
-ENC_TIME_TOD = 4
-ENC_TIME_RTPS = 8
-ENC_TIME_NTP_BASE_ZERO = 14
-ENC_TIME_TIMEVAL = 16
-ENC_TIME_SECS = 18
-ENC_TIME_MSECS = 20
-ENC_TIME_SECS_NTP = 24
-ENC_TIME_RFC_3971 = 32
-ENC_TIME_MSEC_NTP = 34
-ENC_CHARENCODING_MASK = 2147483646
+ENC_NA = 0
+ENC_CHARENCODING_MASK = 65534
 ENC_ASCII = 0
+ENC_ISO_646_IRV = 14
 ENC_UTF_8 = 2
 ENC_UTF_16 = 4
 ENC_UCS_2 = 6
@@ -555,14 +470,28 @@ ENC_ISO_8859_14 = 36
 ENC_ISO_8859_15 = 38
 ENC_ISO_8859_16 = 40
 ENC_WINDOWS_1250 = 42
-ENC_3GPP_TS_23_038_7BITS = 44
+ENC_3GPP_TS_23_038_7BITS_PACKED = 44
+ENC_3GPP_TS_23_038_7BITS = 14
 ENC_EBCDIC = 46
 ENC_MAC_ROMAN = 48
 ENC_CP437 = 50
 ENC_ASCII_7BITS = 52
 ENC_T61 = 54
 ENC_EBCDIC_CP037 = 56
-ENC_NA = 0
+ENC_WINDOWS_1252 = 58
+ENC_WINDOWS_1251 = 60
+ENC_CP855 = 62
+ENC_CP866 = 64
+ENC_ISO_646_BASIC = 66
+ENC_BCD_DIGITS_0_9 = 68
+ENC_KEYPAD_ABC_TBCD = 70
+ENC_KEYPAD_BC_TBCD = 72
+ENC_3GPP_TS_23_038_7BITS_UNPACKED = 76
+ENC_ETSI_TS_102_221_ANNEX_A = 78
+ENC_GB18030 = 80
+ENC_EUC_KR = 82
+ENC_APN_STR = 84
+ENC_ZIGBEE = 1073741824
 ENC_STR_NUM = 16777216
 ENC_STR_HEX = 33554432
 ENC_STRING = 50331648
@@ -574,12 +503,33 @@ ENC_SEP_DASH = 262144
 ENC_SEP_DOT = 524288
 ENC_SEP_SPACE = 1048576
 ENC_SEP_MASK = 2031616
+ENC_BCD_ODD_NUM_DIG = 65536
+ENC_BCD_SKIP_FIRST = 131072
+ENC_TIME_SECS_NSECS = 0
+ENC_TIME_TIMESPEC = 0
+ENC_TIME_NTP = 2
+ENC_TIME_TOD = 4
+ENC_TIME_RTPS = 8
+ENC_TIME_NTP_BASE_ZERO = 8
+ENC_TIME_SECS_USECS = 16
+ENC_TIME_TIMEVAL = 16
+ENC_TIME_SECS = 18
+ENC_TIME_MSECS = 20
+ENC_TIME_SECS_NTP = 24
+ENC_TIME_RFC_3971 = 32
+ENC_TIME_MSEC_NTP = 34
+ENC_TIME_MIP6 = 36
+ENC_TIME_CLASSIC_MAC_OS_SECS = 38
+ENC_TIME_NSECS = 40
 ENC_ISO_8601_DATE = 65536
 ENC_ISO_8601_TIME = 131072
 ENC_ISO_8601_DATE_TIME = 196608
 ENC_RFC_822 = 262144
 ENC_RFC_1123 = 524288
 ENC_STR_TIME_MASK = 983040
+ENC_VARINT_PROTOBUF = 2
+ENC_VARINT_QUIC = 4
+ENC_VARINT_ZIGZAG = 8
 
 
 
@@ -667,24 +617,34 @@ MENU_STAT_GENERIC = 3
 MENU_STAT_CONVERSATION = 4
 MENU_STAT_ENDPOINT = 5
 MENU_STAT_RESPONSE = 6
-MENU_STAT_TELEPHONY = 7
-MENU_STAT_TELEPHONY_ANSI = 8
-MENU_STAT_TELEPHONY_GSM = 9
-MENU_STAT_TELEPHONY_LTE = 10
-MENU_STAT_TELEPHONY_MTP = 11
-MENU_STAT_TELEPHONY_SCTP = 12
-MENU_TOOLS_UNSORTED = 13
+MENU_STAT_RSERPOOL = 7
+MENU_STAT_TELEPHONY = 8
+MENU_STAT_TELEPHONY_ANSI = 9
+MENU_STAT_TELEPHONY_GSM = 10
+MENU_STAT_TELEPHONY_LTE = 11
+MENU_STAT_TELEPHONY_MTP3 = 12
+MENU_STAT_TELEPHONY_SCTP = 13
+MENU_TOOLS_UNSORTED = 14
+
+
+-- the possible values for Pinfo's p2p_dir attribute
+P2P_DIR_UNKNOWN = -1
+P2P_DIR_SENT    =  0
+P2P_DIR_RECV    =  1
 
 
 -- other useful constants
+-- DATA_DIR and USER_DIR have a trailing directory separator.
 GUI_ENABLED = gui_enabled()
-DATA_DIR = Dir.global_config_path()
-USER_DIR = Dir.personal_config_path()
+DATA_DIR = Dir.global_config_path()..package.config:sub(1,1)
+USER_DIR = Dir.personal_config_path()..package.config:sub(1,1)
 
 -- deprecated function names
 datafile_path = Dir.global_config_path
 persconffile_path = Dir.personal_config_path
 
 
-dofile(DATA_DIR.."console.lua")
+if not running_superuser or run_user_scripts_when_superuser then
+    dofile(DATA_DIR.."console.lua")
+end
 --dofile(DATA_DIR.."dtd_gen.lua")
